=====
mchmm
=====

.. image:: https://readthedocs.org/projects/mchmm/badge/?version=latest
    :target: https://mchmm.readthedocs.io/en/latest/?badge=latest
.. image:: https://img.shields.io/github/issues/maximtrp/mchmm.svg
    :target: https://github.com/maximtrp/mchmm/issues
.. image:: https://codecov.io/gh/maximtrp/mchmm/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/maximtrp/mchmm
.. image:: https://app.codacy.com/project/badge/Grade/d7881a827eb9473d89aa1fc10fdd855e
    :target: https://www.codacy.com/gh/maximtrp/mchmm/dashboard
.. image:: https://static.pepy.tech/badge/mchmm
    :target: https://pepy.tech/project/mchmm
.. image:: https://img.shields.io/pypi/v/mchmm.svg
    :target: https://pypi.python.org/pypi/mchmm


*mchmm* is a Python package implementing Markov chains and Hidden Markov models in pure NumPy and SciPy.


Dependencies
------------

* `NumPy <https://www.numpy.org/>`_
* `SciPy <https://www.scipy.org/>`_


Features
--------

* Discrete Markov chains
* Hidden Markov models
